==> wordpress-2.8.5-sw.tar.gz: wordpress/wp-config-sample.php <==
<?php
/** 
 * Konfigaresheni kuu za WordPress.
 *
 * Faili hili lina konfigaresheni zifuatazo: MySQL seting, Prefix za Meza,
 * Vifunguo vya siri, Lugha ya WordPress, na ABSPATH. Unaweza kupata maelekezo zaidi kwa kutembelea
 * {@link http://codex.wordpress.org/Editing_wp-config.php Hariri
 * wp-config.php} Nakala ya Codex. Unaweza kupata seting za MySQL kwa provaida wako.
 *
 * Faili hili linatumiwa na skripti ya utengenezaji wp-config.php wakati wa usadinishaji. 
 * Si lazima kutumia tovuti, unaweza kukopi faili na kujaza data zinazohiajika kwenye "wp-config.php".
 *
 * @package WordPress
 */

// ** MySQL seting - Unaweza kupata data hii kutoka kwa provaida wako ** //
/** Jina la datamakalio kwa ajili ya WordPress */
define('DB_NAME', 'jina-la-datamakalio');

/** Jina la mtumiaji la MySQL */
define('DB_USER', 'jina-la-mtumiaji');

/** Neno la siri la MySQL */
define('DB_PASSWORD', 'neno-la-siri');

/** Jina la hosti la MySQL, mara nyingi localhost */
define('DB_HOST', 'localhost');

/** Charset ya datamakalio kwa ajili ya utengeneza meza za datamakalio. */
define('DB_CHARSET', 'utf8');

/** Aina ya Collate Datamakalio.Usibadilishe kama huna uhakika. */
define('DB_COLLATE', '');

/**#@+
 * Vifunguo vya Uhalisishaji.
 *
 * Badilisha hivi kwa tungo zisizo maarufu!
 * Unaweza kutengeneza hizi kwa kutumia kiungo hiki {@link https://api.wordpress.org/secret-key/1.1/ WordPress.org secret-key service}
 * Unaweza kubadilisha wakati wote kuharimisha kuki zilizopo.Hii itawalazimisha watumiaji waingie tena.
 *
 * @since 2.6.0
 */
define('AUTH_KEY', 'ingiza neno lako la siri hapa');
define('SECURE_AUTH_KEY', 'ingiza neno lako la siri hapa');
define('LOGGED_IN_KEY', 'ingiza neno lako la siri hapa');
define('NONCE_KEY', 'ingiza neno lako la siri hapa');
/**#@-*/

/**
 * Kianzilishi cha meza za datamakalio za WordPress.
 *
 * Unaweza kuwa na masadinisho zaidi ya moja katika datamakalio hiyo hiyo, kila sadinisho likatumia kianzilishi chake.
 * Nambari,herufi, na vialama pekee tafadhali!
 */
$table_prefix  = 'wp_';

/**
 * Lugha ya WordPress,chaguo msingi ni Kiingereza.
 *
 * Badilisha hii kwa lokalaizi WordPress. Jina la faili la MO kwa lugha iliyochaguliwa ni lazima liwekwe kwenye wp-content/languages. 
 * Kwa mfano, kusadinisha kiswahili sw.mo liwekwe wp-content/languages na kuseti WPLANG kuwa 'sw' kuwasha kishwahili.
 */
define ('WPLANG', 'sw');

/* Umemaliza uhariri!Furahia Blogi! */

/** Njia ya dairektori la WordPress*/
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Seti  WordPress vars na mafaili yaliyomo. */
require_once(ABSPATH . 'wp-settings.php');

==> wordpress-3.0.1-sw.tar.gz: wordpress/wp-config-sample.php <==
<?php
/** 
 * Konfigaresheni kuu za WordPress.
 *
 * Faili hili lina konfigaresheni zifuatazo: MySQL seting, Prefix za Meza,
 * Vifunguo vya siri, Lugha ya WordPress, na ABSPATH. Unaweza kupata maelekezo zaidi kwa kutembelea
 * {@link http://codex.wordpress.org/Editing_wp-config.php Hariri
 * wp-config.php} Nakala ya Codex. Unaweza kupata seting za MySQL kwa provaida wako.
 *
 * Faili hili linatumiwa na skripti ya utengenezaji wp-config.php wakati wa usadinishaji. 
 * Si lazima kutumia tovuti, unaweza kukopi faili na kujaza data zinazohiajika kwenye "wp-config.php".
 *
 * @package WordPress
 */

// ** MySQL seting - Unaweza kupata data hii kutoka kwa provaida wako ** //
/** Jina la datamakalio kwa ajili ya WordPress */
define('DB_NAME', 'jina-la-datamakalio');

/** Jina la mtumiaji la MySQL */
define('DB_USER', 'jina-la-mtumiaji');

/** Neno la siri la MySQL */
define('DB_PASSWORD', 'neno-la-siri');

/** Jina la hosti la MySQL, mara nyingi localhost */
define('DB_HOST', 'localhost');

/** Charset ya datamakalio kwa ajili ya utengeneza meza za datamakalio. */
define('DB_CHARSET', 'utf8');

/** Aina ya Collate Datamakalio.Usibadilishe kama huna uhakika. */
define('DB_COLLATE', '');


/**#@+
 * Vifunguo vya Uhalisishaji.
 *
 * Badilisha hivi kwa tungo zisizo maarufu!
 * Unaweza kutengeneza hizi kwa kutumia kiungo hiki {@link https://api.wordpress.org/secret-key/1.1/ WordPress.org secret-key service}
 * Unaweza kubadilisha wakati wote kuharimisha kuki zilizopo.Hii itawalazimisha watumiaji waingie tena.
 *
 * @since 2.6.0
 */
define('AUTH_KEY',         'ingiza neno lako la siri hapa');
define('SECURE_AUTH_KEY',  'ingiza neno lako la siri hapa');
define('LOGGED_IN_KEY',    'ingiza neno lako la siri hapa');
define('NONCE_KEY',        'ingiza neno lako la siri hapa');
define('AUTH_SALT',        'ingiza neno lako la siri hapa');
define('SECURE_AUTH_SALT', 'ingiza neno lako la siri hapa');
define('LOGGED_IN_SALT',   'ingiza neno lako la siri hapa');
define('NONCE_SALT',       'ingiza neno lako la siri hapa');

/**#@-*/

/**
 * Kianzilishi cha meza za datamakalio za WordPress.
 *
 * Unaweza kuwa na masadinisho zaidi ya moja katika datamakalio hiyo hiyo, kila sadinisho likatumia kianzilishi chake.
 * Nambari,herufi, na vialama pekee tafadhali!
 */
$table_prefix  = 'wp_';

/**
 * WordPress Localized Language, defaults to English.
 *
 * Change this to localize WordPress.  A corresponding MO file for the chosen
 * language must be installed to wp-content/languages. For example, install
 * de.mo to wp-content/languages and set WPLANG to 'de' to enable German
 * language support.
 */
define ('WPLANG', 'sw');

/**
 * For developers: WordPress debugging mode.
 *
 * Badilisha hii kwa lokalaizi WordPress. Jina la faili la MO kwa lugha iliyochaguliwa ni lazima liwekwe kwenye wp-content/languages. 
 * Kwa mfano, kusadinisha kiswahili sw.mo liwekwe wp-content/languages na kuseti WPLANG kuwa 'sw' kuwasha kishwahili.
 */
define ('WPLANG', 'sw');

/* Umemaliza uhariri!Furahia Blogi! */

/** Njia ya dairektori la WordPress*/
if ( !defined('ABSPATH') )
	define('ABSPATH', dirname(__FILE__) . '/');

/** Seti  WordPress vars na mafaili yaliyomo. */
require_once(ABSPATH . 'wp-settings.php');
